biom.table.Table.nnz — biom-format.org

# biom-format.org

## biom.table.Table.nnz

« biom.table.Table.matrix_data :: Contents :: biom.table.Table.shape »

# biom.table.Table.nnz

`Table.` `nnz`

  Number of non-zero elements of the underlying contingency matrix

« biom.table.Table.matrix_data :: Contents :: biom.table.Table.shape »

© Copyright 2011-2013, The BIOM Format Development Team. Last updated on Nov 19, 2014. Created using Sphinx 1.2.3.